"use strict";
var TestLoader = (function () {
    function TestLoader(_fileRequirer) {
        this._fileRequirer = _fileRequirer;
    }
    TestLoader.prototype.loadTestFixture = function (filePath) {
        var _this = this;
        var Test = this._fileRequirer.require(filePath);
        var testFixtureKeys = Object.keys(Test);
        var testFixtures = [];
        // if the default export is class constructor
        if (typeof Test === "function") {
            var testFixture = this._loadTestFixture(Test);
            if (testFixture !== null) {
                testFixtures.push(testFixture);
            }
        }
        else {
            testFixtureKeys.forEach(function (testFixtureKey) {
                var testFixture = _this._loadTestFixture(Test[testFixtureKey]);
                if (testFixture !== null) {
                    testFixtures.push(testFixture);
                }
            });
        }
        return testFixtures;
    };
    TestLoader.prototype._loadTestFixture = function (testFixtureConstructor) {
        var testFixture = {};
        testFixture.ignored = false;
        if (Reflect.getMetadata("alsatian:ignore", testFixtureConstructor)) {
            // fixture should be ignored
            testFixture.ignored = true;
        }
        // create an instance of the test fixture
        testFixture.fixture = new testFixtureConstructor();
        // find all the tests on this test fixture
        var tests = Reflect.getMetadata("alsatian:tests", testFixture.fixture);
        testFixture.focussed = false;
        if (Reflect.getMetadata("alsatian:focus", testFixtureConstructor)) {
            testFixture.focussed = true;
        }
        testFixture.tests = [];
        if (tests === undefined) {
            // no tests on the fixture
            return null;
        }
        tests.forEach(function (test) {
            test.ignored = false;
            if (Reflect.getMetadata("alsatian:ignore", testFixture.fixture, test.key)) {
                test.ignored = true;
            }
            test.focussed = false;
            if (Reflect.getMetadata("alsatian:focus", testFixture.fixture, test.key)) {
                test.focussed = true;
            }
            test.timeout = Reflect.getMetadata("alsatian:timeout", testFixture.fixture, test.key) || null;
            testFixture.tests.push(test);
            if (!test.description) {
                test.description = test.key;
            }
            var testCases = Reflect.getMetadata("alsatian:testcases", testFixture.fixture, test.key);
            test.testCases = [];
            if (!testCases) {
                test.testCases.push({ arguments: [] });
            }
            else {
                testCases.forEach(function (testCase) {
                    test.testCases.push(testCase);
                });
            }
        });
        return testFixture;
    };
    return TestLoader;
}());
exports.TestLoader = TestLoader;
//# sourceMappingURL=test-loader.js.map